pub mod mute {
    use teloxide::Bot;
    use teloxide::requests::Requester;
    use tokio::time::{sleep, Duration};
    use chrono::{Duration as ChronoDuration, Local, TimeDelta};
    use teloxide::payloads::RestrictChatMemberSetters;
    use teloxide::types::{ChatId, ChatPermissions, InputFile, Message, MessageKind};

    pub async fn mute_user(
        replied_message: Option<&Message>,
        multiplier: i32,
        time: String,
        bot: &Bot,
        chat_id: ChatId) -> Result<String, String>
    {
        if let None = replied_message {
            bot.send_message(
                chat_id,
                "Ответьте на сообщение человека, которого вы хотите замьютить".to_string()
            ).await.unwrap();
            Err("Ответьте на сообщение человека, которого вы хотите замьютить".to_string())
        } else {
            match &replied_message.unwrap().kind {
                MessageKind::Common(message) => {
                    if let None = message.from {
                        bot.send_message(chat_id, "Сообщение не найдено").await.unwrap();
                        Err("Сообщение не найдено".to_string())
                    } else if let Some(user) = &message.from {
                        match time.as_str() {
                            "w" | "d" | "h" | "m" => {
                                let dice_value = bot.send_dice(chat_id)
                                    .await
                                    .unwrap()
                                    .dice()
                                    .unwrap()
                                    .value;

                                let time_value = (multiplier * dice_value) as i64;

                                let mute_duration : (TimeDelta, &str) = match time.as_str() {
                                    "w" => (ChronoDuration::weeks(time_value), "недель"),
                                    "d" => (ChronoDuration::days(time_value), "дней"),
                                    "h" => (ChronoDuration::hours(time_value), "часов"),
                                    "m" => (ChronoDuration::minutes(time_value), "минут"),
                                    _ => (ChronoDuration::weeks(time_value), "недель"),
                                };

                                let duration = Local::now().naive_utc() + mute_duration.0;

                                sleep(Duration::from_secs(4)).await ;

                                match bot.restrict_chat_member(
                                    chat_id,
                                    user.id,
                                    ChatPermissions::from_bits(0).unwrap()
                                ).until_date(duration.and_utc())
                                    .await
                                {
                                    Ok(_) => {
                                        bot.send_message(
                                            chat_id,
                                            format!("На пользователя {} повесили железный зановес на {} {}",
                                                    user.first_name,
                                                    multiplier * dice_value, mute_duration.1
                                            )
                                        ).await
                                            .unwrap();
                                        bot.send_sticker(
                                            chat_id,
                                            InputFile::file_id("CAACAgIAAxkBAAEpgP1lzmlmReALF20lHlRRGRvQ_SSCDAACqjwAAiIpSUkOv2XNIRmlYTQE")
                                        ).await.unwrap();
                                        Ok("Демократия была совершена".to_string())
                                    }
                                    Err(error) => {
                                        bot.send_message(
                                            chat_id,
                                            error.to_string().to_string()
                                        ).await
                                            .unwrap();
                                        Err(error.to_string())
                                    }
                                }
                            },
                            _ => {
                                bot.send_message(chat_id, "Напишите меру времени")
                                    .await
                                    .unwrap();
                                Err("Напишите меру времени".to_string())
                            }
                        }
                    } else {
                        bot.send_message(chat_id, "Ошибка номер хуй")
                            .await
                            .unwrap();
                        Err("Ошибка номер хуй".to_string())
                    }
                }
                _ => {
                    Err("тест".to_string())
                }
            }
        }
    }
}