use std::{error::Error};
use teloxide::{Bot, types::Message};

#[path="../enums/commands.rs"]
mod commands;
#[path= "main_handler_endpoints.rs"]
mod main_handler_endpoints;

use main_handler_endpoints::main_handler_endpoints::*;

pub mod main_handler{

    use super::{*, commands::enum_commands::Commands};
    use teloxide::{dptree::case, filter_command, types::Update, dispatching::{Dispatcher, UpdateFilterExt}};

    pub async fn main_handler_spawn(bot: Bot) -> () {
        let command_handler = filter_command::<Commands, Result<(), Box<(dyn Error + Send + Sync + 'static)>>>()
            .branch(case![Commands::Facker].endpoint(facker_endpoint))
            .branch(
                case![Commands::DemocracyMute(multiplier, time_type)]
                    .endpoint(|bot : Bot, msg : Message, args : (i32, String)| async move {
                        mute_endpoint(bot, msg, args.0, args.1).await
                    }))
            .branch(case![Commands::DemocracyUnmute].endpoint(unmute_endpoint))
            .branch(case![Commands::Tribunal(reason)]
                .endpoint(|bot : Bot, msg : Message, args| async move {
                    tribunal_endpoint(bot, msg, args).await
                }));

        let message_handler = Update::filter_message()
            .branch(command_handler);

        Dispatcher::builder(bot, message_handler)
            .build()
            .dispatch()
            .await;
    }
}